package com.jeeplus.business.borrow.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.jeeplus.business.borrow.domain.BorrowMoney;
import com.jeeplus.business.borrow.service.BorrowService;
import com.jeeplus.business.borrow.service.dto.BorrowDTO;
import com.jeeplus.business.borrow.service.dto.RefundDTO;
import com.jeeplus.common.utils.ResponseUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

@Api("借款管理")
@RestController
@RequestMapping(value = "/borrow")
public class BorrowController {

    @Resource
    private BorrowService borrowService;



    /**
     * 借款管理列表
     */
    @ApiOperation(value = "借款管理列表")
    @GetMapping(value = "/findList")
    public ResponseEntity<IPage<BorrowDTO>> applyList(BorrowDTO borrowDTO, Page<BorrowDTO> page) throws Exception {
        IPage<BorrowDTO> pageList=borrowService.findPageList(borrowDTO,page);
        return ResponseEntity.ok(pageList);
    }

    /**
     * 根据id查询数据
     */
    @ApiOperation(value = "根据id查询数据")
    @GetMapping(value = "findById")
    public ResponseEntity<BorrowDTO> findById(@RequestParam String id){
        BorrowDTO borrowDTO=borrowService.findById(id);
        return ResponseEntity.ok(borrowDTO);
    }

    /**
     * 新增或修改
     */
    @ApiOperation(value = "新增或修改")
    @PostMapping(value = "/saveForm")
    public ResponseEntity saveForm(@RequestBody BorrowDTO borrowDTO) throws Exception {
        String id=borrowService.save(borrowDTO);
        return ResponseUtil.newInstance().add("businessTable","jy_borrow_money").add("businessId",id).ok("操作成功");
    }

    /**
     * 根据id修改状态status
     * @param
     */
    @ApiOperation(value = "根据id修改状态status")
    @PostMapping(value = "/updateStatusById")
    public void updateStatusById(@RequestBody BorrowDTO borrowDTO) {
        borrowService.updateStatusById(borrowDTO);
    }

    /**
     * 根据id进行删除
     */
    @ApiOperation(value = "根据id进行删除")
    @DeleteMapping(value = "/delete")
    public ResponseEntity<String> deleteById(@RequestParam String id){
        String s = borrowService.deleteById(id);
        return ResponseEntity.ok(s);
    }

    /**
     * 添加/修改借款归还
     */
    @ApiOperation(value = "新增或修改借款归还")
    @PostMapping(value = "/saveRefund")
    public ResponseEntity saveRefund(@RequestBody RefundDTO refundDTO) throws Exception {
        String id=borrowService.saveRefund(refundDTO);
        return ResponseUtil.newInstance().add("businessTable","jy_refund").add("businessId",id).ok("操作成功");
    }

    /**
     * 根据id修改状态status
     * @param
     */
    @ApiOperation(value = "根据id修改状态status")
    @PostMapping(value = "/updateRefundById")
    public void updateRefundById(@RequestBody RefundDTO refundDTO) {
        borrowService.updateRefundById(refundDTO);
    }


    /**
     * 管理员修改
     */
    @ApiOperation(value = "管理员修改")
    @PostMapping(value = "/adminEditForm")
    public void adminEditForm(@RequestBody BorrowDTO borrowDTO){
        borrowService.adminEditForm(borrowDTO);
    }


    /**
     * 根据当前登录人查找借款信息
     */
    @ApiOperation(value = "根据当前登录人查找信息")
    @GetMapping(value = "listByUserId")
    public ResponseEntity<IPage<BorrowMoney>> listByUserId(BorrowMoney borrowMoney, Page<BorrowDTO> page) throws Exception {
        IPage<BorrowMoney> pageList=borrowService.listByUserId(borrowMoney,page);
        return ResponseEntity.ok(pageList);
    }

}
