package com.jeeplus.business.drive.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.jeeplus.business.drive.service.DriveAccountService;
import com.jeeplus.business.drive.service.DriveApplyService;
import com.jeeplus.business.drive.service.dto.DriveAccountDTO;
import com.jeeplus.business.drive.service.dto.DriveApplyDTO;
import com.jeeplus.business.drive.service.dto.DriveDTO;
import com.jeeplus.business.meetingRoom.service.dto.MeetingRoomDTO;
import com.jeeplus.common.utils.ResponseUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

@Slf4j
@Api(tags ="用车申请及结算管理")
@RestController
@RequestMapping(value = "/drive")
public class DriveController {

    @Resource
    private DriveAccountService driveAccountService;

    @Resource
    private DriveApplyService driveApplyService;


    /**
     * 用车申请列表
     */
    @ApiOperation(value = "用车申请列表")
    @GetMapping(value = "/applyList")
    public ResponseEntity<IPage<DriveApplyDTO>> applyList(DriveApplyDTO driveApplyDTO, Page<DriveApplyDTO> page) throws Exception {
        IPage<DriveApplyDTO> pageList=driveApplyService.findPageList(driveApplyDTO,page);
        return ResponseEntity.ok(pageList);
    }

    /**
     * 新增/修改
     */
    @ApiOperation(value = "新增或修改")
    @PostMapping(value = "/saveForm")
    public ResponseEntity saveForm(@RequestBody DriveApplyDTO driveApplyDTO){
        String id=driveApplyService.save(driveApplyDTO);
        return ResponseUtil.newInstance().add("businessTable","jy_drive_apply").add("businessId",id).ok("操作成功");
    }


    /**
     * 根据id查找用车申请信息
     */
    @ApiOperation(value = "根据id查找用车申请")
    @GetMapping(value = "findById")
    public ResponseEntity<DriveApplyDTO> findById(@RequestParam String id){
        DriveApplyDTO applyDTO=driveApplyService.findById(id);
        return ResponseEntity.ok(applyDTO);
    }

    /**
     * 根据id修改状态status
     * @param
     */
    @ApiOperation(value = "根据id修改状态status")
    @PostMapping(value = "/updateStatusById")
    public void updateStatusById(@RequestBody DriveApplyDTO driveApplyDTO) {
        driveApplyService.updateStatusById(driveApplyDTO);
    }

    /**
     * 根据id进行删除
     */
    @ApiOperation(value = "根据id进行删除")
    @DeleteMapping(value = "/delete")
    public ResponseEntity<String> deleteById(@RequestParam String id){
        String s = driveApplyService.deleteById(id);
        return ResponseEntity.ok(s);
    }

    /**
     * 新增/修改  用车结算
     */
    @ApiOperation(value = "新增或修改 用车结算")
    @PostMapping(value = "/saveAccountForm")
    public ResponseEntity saveAccountForm(@RequestBody DriveAccountDTO driveAccountDTO){
        String id=driveApplyService.saveAccountForm(driveAccountDTO);
        return ResponseUtil.newInstance().add("businessTable","jy_drive_account").add("businessId",id).ok("操作成功");
    }

    /**
     * 根据申请id修改状态status
     * @param
     */
    @ApiOperation(value = "根据申请id修改状态status")
    @PostMapping(value = "/updateStatusByApplyId")
    public void updateStatusByApplyId(@RequestBody DriveAccountDTO driveAccountDTO) {
        driveApplyService.updateStatusByApplyId(driveAccountDTO);
    }


    /**
     * 管理员修改
     */
    @ApiOperation(value = "管理员修改")
    @PostMapping(value = "/adminEditForm")
    public ResponseEntity adminEditForm(@RequestBody DriveDTO driveDTO){
        driveApplyService.adminEditForm(driveDTO);
        return ResponseEntity.ok("操作成功");
    }










}
